==> estateplat-common-1.2.4-20191212.063146-213-sources.jar: cn/gtmap/estateplat/model/server/core/BdcGdxx.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * Created by zdd on 2016/1/7.
 * 不动产登记项目的归档信息
 */
@Table(name = "bdc_gdxx")
public class BdcGdxx {

    @Id
    private String gdxxid;//主键
    private String xmid;//项目ID
    private String daid;//档案ID
    private String mlh;//目录号
    private String ajh;//案卷号
    private Date gdrq;//归档日期
    private String gdr;//归档人
    private String gdxx;//归档信息
    private String bz;//备注
    private Integer ajjs;//案卷件数
    private Integer ajys;//案卷页数
    private String hh;//盒号
    private String dah;//档案号
    private String gdlx;//归档类型
    private String gxzt;

    public String getGdxxid() {
        return gdxxid;
    }

    public void setGdxxid(String gdxxid) {
        this.gdxxid = gdxxid;
    }

    public String getXmid() {
        return xmid;
    }

    public void setXmid(String xmid) {
        this.xmid = xmid;
    }

    public String getDaid() {
        return daid;
    }

    public void setDaid(String daid) {
        this.daid = daid;
    }

    public String getMlh() {
        return mlh;
    }

    public void setMlh(String mlh) {
        this.mlh = mlh;
    }

    public String getAjh() {
        return ajh;
    }

    public void setAjh(String ajh) {
        this.ajh = ajh;
    }

    public Date getGdrq() {
        return gdrq;
    }

    public void setGdrq(Date gdrq) {
        this.gdrq = gdrq;
    }

    public String getGdr() {
        return gdr;
    }

    public void setGdr(String gdr) {
        this.gdr = gdr;
    }

    public String getGdxx() {
        return gdxx;
    }

    public void setGdxx(String gdxx) {
        this.gdxx = gdxx;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public Integer getAjjs() {
        return ajjs;
    }

    public void setAjjs(Integer ajjs) {
        this.ajjs = ajjs;
    }

    public Integer getAjys() {
        return ajys;
    }

    public void setAjys(Integer ajys) {
        this.ajys = ajys;
    }

    public String getHh() {
        return hh;
    }

    public void setHh(String hh) {
        this.hh = hh;
    }

    public String getDah() {
        return dah;
    }

    public void setDah(String dah) {
        this.dah = dah;
    }

    public String getGdlx() {
        return gdlx;
    }

    public void setGdlx(String gdlx) {
        this.gdlx = gdlx;
    }

    public String getGxzt() {
        return gxzt;
    }

    public void setGxzt(String gxzt) {
        this.gxzt = gxzt;
    }
}

==> estateplat-common-1.2.4-20191220.012421-227-sources.jar: cn/gtmap/estateplat/model/server/core/BdcGdxx.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * Created by zdd on 2016/1/7.
 * 不动产登记项目的归档信息
 */
@Table(name = "bdc_gdxx")
public class BdcGdxx {

    @Id
    private String gdxxid;//主键
    private String xmid;//项目ID
    private String daid;//档案ID
    private String mlh;//目录号
    private String ajh;//案卷号
    private Date gdrq;//归档日期
    private String gdr;//归档人
    private String gdxx;//归档信息
    private String bz;//备注
    private Integer ajjs;//案卷件数
    private Integer ajys;//案卷页数
    private String hh;//盒号
    private String dah;//档案号
    private String gdlx;//归档类型
    private String gxzt;
    private String sjly;//数据来源

    public String getGdxxid() {
        return gdxxid;
    }

    public void setGdxxid(String gdxxid) {
        this.gdxxid = gdxxid;
    }

    public String getXmid() {
        return xmid;
    }

    public void setXmid(String xmid) {
        this.xmid = xmid;
    }

    public String getDaid() {
        return daid;
    }

    public void setDaid(String daid) {
        this.daid = daid;
    }

    public String getMlh() {
        return mlh;
    }

    public void setMlh(String mlh) {
        this.mlh = mlh;
    }

    public String getAjh() {
        return ajh;
    }

    public void setAjh(String ajh) {
        this.ajh = ajh;
    }

    public Date getGdrq() {
        return gdrq;
    }

    public void setGdrq(Date gdrq) {
        this.gdrq = gdrq;
    }

    public String getGdr() {
        return gdr;
    }

    public void setGdr(String gdr) {
        this.gdr = gdr;
    }

    public String getGdxx() {
        return gdxx;
    }

    public void setGdxx(String gdxx) {
        this.gdxx = gdxx;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public Integer getAjjs() {
        return ajjs;
    }

    public void setAjjs(Integer ajjs) {
        this.ajjs = ajjs;
    }

    public Integer getAjys() {
        return ajys;
    }

    public void setAjys(Integer ajys) {
        this.ajys = ajys;
    }

    public String getHh() {
        return hh;
    }

    public void setHh(String hh) {
        this.hh = hh;
    }

    public String getDah() {
        return dah;
    }

    public void setDah(String dah) {
        this.dah = dah;
    }

    public String getGdlx() {
        return gdlx;
    }

    public void setGdlx(String gdlx) {
        this.gdlx = gdlx;
    }

    public String getGxzt() {
        return gxzt;
    }

    public void setGxzt(String gxzt) {
        this.gxzt = gxzt;
    }

    public String getSjly() {
        return sjly;
    }

    public void setSjly(String sjly) {
        this.sjly = sjly;
    }
}
